@@ -1,20 +1,25 @@
 /*
  * All data is in subdirectories of DATADIR, by default /usr/lib/kbd
- * The following four subdirectories are defined:
+ * The following five subdirectories are defined:
  */
-#define KEYMAPDIR "keytables"
-#define FONTDIR "consolefonts"
+#define KEYMAPDIR "keymaps"
+#define UNIMAPDIR "unimaps"
 #define TRANSDIR "consoletrans"
 #define VIDEOMODEDIR "videomodes"
+#define FONTDIR "consolefonts"
+/* subdir of the latter */
+#define PARTIALDIR "partialfonts"
+/* obsolete */
+#define OLDKEYMAPDIR "keytables"
 
 /*
  * Default keymap, and where the kernel copy of it lives.
  */
-#ifdef sparc
-# define DEFMAP "sunkeymap.map"
+#ifdef __sparc__
+# define DEFMAP "sunkeymap.kmap"
 # define KERNDIR "/usr/src/linux/drivers/sbus/char"
 #else
-# define DEFMAP "defkeymap.map"
+# define DEFMAP "defkeymap.kmap"
 # define KERNDIR "/usr/src/linux/drivers/char"
 #endif
 
